// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The bytran logo is distributed under the Creative Commons 3.0 Attribution License: https://creativecommons.org/licenses/by/3.0/us/
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


// Component is used to authenticate with the HITRAN server (it is currently possible to access the HITRAN server without authentication but this open access functionality may be terminated in the future)
import QtQuick 2.9
import QtQuick.Controls 2.2
import QtQuick.Layouts 1.3

Item {

    id: authenticateItem
    anchors.fill: parent

    // Rectangle to shade the background
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: 'black'
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        anchors.fill: mainAuthenticateColumnLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        color: "white"
        border.width: 1
        border.color: 'gray'
        radius: coreObj.defaultLabelHeight * 0.5
    }

    // Exit button
    CustomButton {
        id: exitButton
        anchors.top: authenticateItem.top
        anchors.right: authenticateItem.right
        anchors.margins: coreObj.defaultLabelHeight * (0.1)
        implicitWidth: 1.5 * exitButton.height
        text: qsTr("X")
        onClicked: authenticateItem.destroy()
    }

    CustomLabel {
        id: widthLabel
        text: qsTr("The optical pathlength units and value")
        visible: false
        enabled: false
    }

    // Column layout to hold all the interface items
    ColumnLayout {
        id: mainAuthenticateColumnLayout
        anchors.centerIn: parent

        CustomLabel {
            text: qsTr("The information entered below will be used to\nconnect to the HITRANonline (hitran.org) server")
        }
        CustomLabel {
            id: emailAddressLabel
            text: qsTr("Email address:")
        }
        CustomTextField {
            Layout.fillWidth: true
            id: emailAddressTextField
        }
        CustomLabel {
            id: passwordLabel
            text: qsTr("Password:")
        }
        CustomTextField {
            Layout.fillWidth: true
            id: passwordTextField
        }
        RowLayout {
            id: optionsRowLayout
            Layout.fillWidth: true

            CustomCheckBox {
                id: storeUserNameCheckBox
                text: qsTr("Store\nemail")
            }
            CustomCheckBox {
                id: storePasswordCheckBox
                text: qsTr("Store\npasswd")
            }
            CustomCheckBox {
                id: showPasswordCheckBox
                text: qsTr("Show\npasswd")
            }
        }
        CustomDialogButtonWithBackground {
            id: testAuthButton
            Layout.fillWidth: true
            text: qsTr("Test authentication")
        }
    }
}
