// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component to connect bytran to external devices via serial port (RS-232) or Bluetooth for device integration purposes
import QtQuick 2.9
import QtQuick.Controls 2.2
import QtQuick.Layouts 1.3
import QtQuick.Window 2.3

Item {

    id: bluetoothClientConnectItem
    anchors.fill: parent

    onHeightChanged:
    {
        // Need to see if can come up with a better solution than just assigning the item height like that
        if (Screen.primaryOrientation === Qt.PortraitOrientation)
        {
            protocolBorderRect.rotation = 0
            protocolButton.rotation = 0
            protocolButton.anchors.topMargin = 0
            protocolButton.anchors.leftMargin = 0
        }
        else
        {
            protocolBorderRect.rotation = 270
            protocolButton.rotation = 270
            protocolButton.anchors.topMargin = - 0.5 * protocolButton.width - 0.5 * protocolButton.height - coreObj.defaultLabelHeight * 0.85
            protocolButton.anchors.leftMargin = - 0.5 * protocolButton.width - 0.5 * protocolButton.height - coreObj.defaultLabelHeight * 0.85
        }

        if (Screen.primaryOrientation === Qt.PortraitOrientation) { mainBluetoothConnectColumnLayout.height = bluetoothClientConnectItem.height - exitButton.height * 3.5; }
        else { mainBluetoothConnectColumnLayout.height = bluetoothClientConnectItem.height + coreObj.defaultLabelHeight * (-1.7); }
    }

    // Rectangle to shade the background
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: 'black'
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        id: formBorderRect
        anchors.fill: mainBluetoothConnectColumnLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        color: "white"
        border.width: 1
        border.color: 'gray'
        radius: coreObj.defaultLabelHeight * 0.5
    }

    // Exit button
    CustomButton {
        id: exitButton
        anchors.top: bluetoothClientConnectItem.top
        anchors.right: bluetoothClientConnectItem.right
        anchors.margins: coreObj.defaultLabelHeight * 0.1
        implicitWidth: 1.5 * exitButton.height
        text: qsTr("X")
        onClicked: {
            bluetoothClientConnectItem.destroy();
        }
    }

    Rectangle {
        id: protocolBorderRect
        anchors.fill: protocolButton
        anchors.margins: coreObj.defaultLabelHeight * (-0.85) + 1
        color: "white"
        border.width: 1
        border.color: 'white'
        radius: coreObj.defaultLabelHeight * 0.5
        visible: remoteControlQml.communicationMode === 0 ? false : true
    }
    CustomDialogButtonWithBackground {
        id: protocolButton
        anchors.top: formBorderRect.bottom
        anchors.left:  mainBluetoothConnectColumnLayout.left
        text: qsTr("  How to use?  ")
        visible: remoteControlQml.communicationMode === 0 ? false : true
        onClicked: remoteControlQml.openUrl("http://www.bytran.org/bluetooth.htm")
        onRotationChanged: { bluetoothColumnLayout.update(); }
    }

    CustomLabel {
        id: widthLabel
        text: qsTr("Connect a slave bluetooth device to be used for")
        visible: false
        enabled: false
    }

    // Column layout to hold all the interface items
    ColumnLayout {
        id: mainBluetoothConnectColumnLayout
        anchors.centerIn: parent
        anchors.horizontalCenter: connectItem.horizontalCenter
        anchors.top: (Screen.primaryOrientation === Qt.PortraitOrientation) ? exitButton.bottom : bluetoothClientConnectItem.top
        anchors.topMargin: coreObj.defaultLabelHeight * 1.2
        anchors.bottom: bluetoothClientConnectItem.bottom
//        anchors.bottomMargin: (Screen.primaryOrientation === Qt.PortraitOrientation) ? coreObj.defaultLabelHeight * 1.2 + protocolButton.height : 1.2 + protocolButton.height
//        onHeightChanged: resizeComponent()

        CustomLabel {
            id: commentLabel
            anchors.top: mainBluetoothConnectColumnLayout.top
            text: qsTr("Connect a slave bluetooth device to be used for\noperating bytran remotely and to retrieve results.")
            // onHeightChanged: resizeComponent()
        }

        // Bluetooth item to set the bluetooth connections
        ColumnLayout {
            id: bluetoothColumnLayout
            anchors.top: commentLabel.bottom
            anchors.bottom:  mainBluetoothConnectColumnLayout.bottom
            anchors.topMargin: mainBluetoothConnectColumnLayout.spacing

            Rectangle {
                id: bluetoothDevicesRect
                border.color: 'gray'
                anchors.top: bluetoothColumnLayout.top
                anchors.left: bluetoothColumnLayout.left
                anchors.right: bluetoothColumnLayout.right
                anchors.bottom: connectAndDiscoverButtonsLayout.top
                anchors.bottomMargin: mainBluetoothConnectColumnLayout.spacing

                ListView {
                    id: bluetoothConnectListView
                    anchors.fill: parent
                    model: remoteControlBluetoothListModel
                    clip: true
                    currentIndex: remoteControlQml.selectedBluetoothDeviceIndex
                    onCurrentIndexChanged: remoteControlQml.selectedBluetoothDeviceIndex = currentIndex

                    delegate: RowLayout {
                        id: listViewRowItem
                        anchors.left: parent.left
                        anchors.right: parent.right

                        CustomLabel {
                            id: rowListLabel
                            text: model.deviceName
                            Layout.fillWidth: parent.width
                            padding: 10
                        }

                        // Mouse area to capture the selection event for a particular item in a list
                        MouseArea {
                            anchors.fill: parent
                            onClicked: bluetoothConnectListView.currentIndex = index
                        }
                    }

                    highlight:
                        Rectangle {
                        color: '#f5b7b1'
                        border.color: 'red'
                        border.width: 1
                    }
                }
            }

            RowLayout {
                id: connectAndDiscoverButtonsLayout
                anchors.bottomMargin: mainBluetoothConnectColumnLayout.spacing
                anchors.bottom: bluetoothBroadcastManualInputRowLayout.top

                RowLayout {
                    id: buttonsRowLayout
                    anchors.centerIn: parent

                    CustomDialogButtonWithBackgroundSmall {
                        id: scanButton
                        implicitWidth: widthLabel.width - connectButton.width
                        text: qsTr("  Discover devices  ")
                        onClicked: remoteControlQml.discoverDevices();
                    }
                    CustomDialogButtonWithBackgroundSmall {
                        id: connectButton
                        anchors.right: buttonsRowLayout.right
                        anchors.leftMargin: mainBluetoothConnectColumnLayout.spacing
                        text: remoteControlQml.connectButtonText
                        onClicked: remoteControlQml.connectBluetooth();
                    }
                }
            }

            RowLayout {
                id: bluetoothBroadcastManualInputRowLayout
                anchors.bottom: bluetoothColumnLayout.bottom

                CustomLabel {
                    id: bluetoothBroadcastManualInputAuxLabel
                    text: qsTr("Broadcast manual input: ")
                    MouseArea {
                        anchors.fill: parent
                        onClicked: bluetoothBroadcastManualInputSwitch.checked = !bluetoothBroadcastManualInputSwitch.checked
                    }
                }
                CustomLabel {
                    id: bluetoothBroadcastManualInputNoAuxLabel
                    text: qsTr("No")
                    color: 'gray'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: remoteControlQml.broadcastManualInput = false
                    }
                }
                CustomSwitch {
                    id: bluetoothBroadcastManualInputSwitch
                    padding: 0
                    checked: remoteControlQml.broadcastManualInput
                    onCheckedChanged: remoteControlQml.broadcastManualInput = checked
                }
                CustomLabel {
                    id: bluetoothBroadcastManualInputYesAuxLabel
                    text: qsTr("Yes")
                    color: 'red'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: remoteControlQml.broadcastManualInput = true
                    }
                }
            }
        }
    }
}
