// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Custom QML component to change the color used to display spectra for different molecules
import QtQuick 2.9
import QtQuick.Controls 2.2
import QtQuick.Layouts 1.3
import QtQuick.Window 2.3
import ColorPlot 1.0

Item {

    id: colorDialogItem
    anchors.fill: parent

    // Adjusting the window size when the phone is rotated
    onHeightChanged:
    {
        if ((Screen.primaryOrientation === Qt.PortraitOrientation))
        {
            colorColumnLayout.height = colorDialogItem.height - exitButton.height - 1.55 * coreObj.defaultLabelHeight - exitButton.padding
            colorColumnLayout.anchors.top = exitButton.bottom
            titleLabel.text = " Select color to be used for plotting spectrum "
        }
        else
        {
            colorColumnLayout.height = colorDialogItem.height - 1.55 * coreObj.defaultLabelHeight
            colorColumnLayout.anchors.top = colorDialogItem.top
            titleLabel.text = "       Select color to be used for plotting spectrum       "
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        id: backRect
        anchors.fill: parent
        border.width: 1
        border.color: "black"
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        id: frameRect
        anchors.fill: colorColumnLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        anchors.bottomMargin: coreObj.defaultLabelHeight * (-0.4)
        color: "white"
        border.width: 1
        border.color: "gray"
        radius: coreObj.defaultLabelHeight * 0.5
    }

    // QML component is used in order to notify the user about the developer
    ColumnLayout {
        id: colorColumnLayout
        anchors.top: exitButton.bottom
        anchors.topMargin: coreObj.defaultLabelHeight
        anchors.horizontalCenter: colorDialogItem.horizontalCenter

        // Label containing the title for the current window
        CustomLabel {
            id: titleLabel
            anchors.top: colorColumnLayout.top
            text: "    Select color to be used for ploting spectrum    "
        }

        ColorPlot {
            id: colorPlot
            Layout.fillWidth: true
            anchors.top: titleLabel.bottom
            anchors.topMargin: 1
            anchors.bottom: colorSlider.top
            color: molListViewModel.selectedColor
            onColorChanged: molListViewModel.selectedColor = colorPlot.color
            colorBarHeight: coreObj.defaultLabelHeight * 2
            onHueValueChanged: colorSlider.value = hueValue
            hueValue: colorSlider.value
            selectorWidth: coreObj.defaultLabelHeight * 4

            MouseArea {
                id: plotMouseArea
                anchors.fill: parent
                onClicked: {
                    colorPlot.x = mouseX
                    colorPlot.y = mouseY
                }
                onPositionChanged: {
                    colorPlot.x = mouseX
                    colorPlot.y = mouseY
                }
            }
        }

        Slider {
            id: colorSlider
            Layout.fillWidth: true
            anchors.bottom: colorColumnLayout.bottom
            // tickmarksEnabled: false
            // updateValueWhileDragging: true
            snapMode: Slider.SnapAlways
            from: 0
            to: 359
            stepSize: 0
            value: colorPlot.hueValue
            onPositionChanged: value = position * 359
            onValueChanged: colorPlot.hueValue = value
        }
    }

    // Exit button
    CustomButton {
        id: exitButton
        anchors.top: colorDialogItem.top
        anchors.right: colorDialogItem.right
        anchors.margins: coreObj.defaultLabelHeight * (0.1)
        implicitWidth: 1.5 * exitButton.height
        text: qsTr("X")
        onClicked: {
            molListViewModel.updateActiveColor();
            colorDialogItem.destroy();
        }
    }
}

