// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component to specify the spectral pathlength
import QtQuick 2.9
import QtQuick.Controls 2.2
import QtQuick.Layouts 1.3

Item {

    id: pathlengthItem
    anchors.fill: parent

    // Rectangle to shade the background
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: 'black'
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        anchors.fill: mainPathlengthColumnLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        color: "white"
        border.width: 1
        border.color: 'gray'
        radius: coreObj.defaultLabelHeight * 0.5
    }

    // Exit button
    CustomButton {
        id: exitButton
        anchors.top: pathlengthItem.top
        anchors.right: pathlengthItem.right
        anchors.margins: coreObj.defaultLabelHeight * (0.1)
        implicitWidth: 1.5 * exitButton.height
        text: qsTr("X")
        onClicked: pathlengthItem.destroy()
    }

    CustomLabel {
        id: widthLabel
        text: qsTr("The optical pathlength units and value")
        visible: false
        enabled: false
    }

    // Column layout to hold all the interface items
    ColumnLayout {
        // At rotation the buttons are not positioned exactly the way they should be (fix this)
        id: mainPathlengthColumnLayout
        anchors.centerIn: parent
        spacing: 5
        CustomLabel {
            id: commentLabel
            Layout.fillWidth: true            
            text: qsTr("The optical pathlength units and value")
        }

        GridLayout {
            id: mainGridLayout

            // Changing the Pathlength value
            CustomLabel {
                id: pathValueLabel
                anchors.right: pathlengthTextField.left
                Layout.column: 0
                Layout.row: 0
                text: qsTr("Pathlength:  ")
            }            
            CustomTextField {
                id: pathlengthTextField
                Layout.column: 1
                Layout.row: 0                
                implicitWidth: widthLabel.width - pathValueLabel.width
                text: pathlengthQml.pathlength
                onEditingFinished: {
                    pathlengthQml.pathlength = text
                    remoteControlQml.broadcastCommand("PATH", 0)
                }
            }
        }

        // ComboBox to select the pathlength units
        CustomComboBox {
            id: unitsComboBox
            Layout.fillWidth: true
            implicitWidth: widthLabel.width
            model: [ "Kilometers, km", "Meters, m", "Centimeters, cm", "Miles, mi", "Feet, ft", "Inches, in"]
            currentIndex: pathlengthQml.units
            onCurrentIndexChanged: pathlengthQml.units = currentIndex
        }
    }
}
