// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component with the cumulative sensors information
import QtQuick 2.9
import QtQuick.Controls 2.2
import QtQuick.Layouts 1.3
import QtQuick.Window 2.3

Item {

    id: sensorsItem
    anchors.fill: parent

    // When the screen is rotated adjusting the position and orientation of the button used to search for phones with sensors
    onHeightChanged:
    {
        if (Screen.primaryOrientation === Qt.PortraitOrientation)
        {
            sensorTagBorderRect.rotation = 0
            sensorTag.rotation = 0
            onSensorTagRowLabel.rotation = 0
            offSensorTagRowLabel.rotation = 0
            sensorTag.anchors.topMargin = coreObj.defaultLabelHeight * (-0.21)
            sensorTag.anchors.leftMargin = 0
        }
        else
        {
            sensorTagBorderRect.rotation = 270
            sensorTag.rotation = 270
            onSensorTagRowLabel.rotation = 90
            offSensorTagRowLabel.rotation = 90
            sensorTag.anchors.topMargin = - 0.5 * sensorTag.width - 0.5 * sensorTag.height - coreObj.defaultLabelHeight * 0.85
            sensorTag.anchors.leftMargin = - 0.5 * sensorTag.width - 0.5 * sensorTag.height - coreObj.defaultLabelHeight * 0.85
        }
    }

    // Rectangle to shade the background
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: 'black'
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        id: formBorderRect
        anchors.fill: mainSensorsColumnLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        color: "white"
        border.width: 1
        border.color: 'gray'
        radius: coreObj.defaultLabelHeight * 0.5
    }

    // Exit button
    CustomButton {
        id: exitButton
        anchors.top: sensorsItem.top
        anchors.right: sensorsItem.right
        anchors.margins: coreObj.defaultLabelHeight * (0.1)
        implicitWidth: 1.5 * exitButton.height
        text: qsTr("X")
        onClicked: sensorsItem.destroy()
    }

    Rectangle {
        id: sensorTagBorderRect
        anchors.fill: sensorTag
        anchors.margins: coreObj.defaultLabelHeight * (-0.85) + 1
        color: "white"
        border.width: 1
        border.color: 'white'
        radius: coreObj.defaultLabelHeight * 0.5
    }
    GridLayout {
        flow: GridLayout.LeftToRight
        id: sensorTag
        anchors.top: formBorderRect.bottom
        anchors.left: mainSensorsColumnLayout.left

        CustomDialogButtonWithBackgroundTwoRow {
            id: connectSensorTagButton
            text: qsTr(" Connect \n SensorTag ")
            Layout.column: (Screen.primaryOrientation === Qt.PortraitOrientation) ? 0 : 1

            // Opening another window with information about the application
            onClicked: {
                var component = Qt.createComponent("SensorTagConnect.qml")
                if (component.status === Component.Ready)
                {
                    sensorTagConnectWindow = component.createObject(sensorsItem)
                }
                sensorTagConnectWindow.show()
            }
        }

        ColumnLayout {
            id: useSensorTagColumnLayout
            Layout.column: (Screen.primaryOrientation === Qt.PortraitOrientation) ? 1 : 0

            // Comment label
            RowLayout {
                id: useSensorTagRowLayout
                anchors.left: useSensorTagColumnLayout.left
                anchors.right: useSensorTagColumnLayout.right
                CustomLabel {
                    id: useSensorTagLabel
                    anchors.centerIn: parent
                    text: qsTr("Use SensorTag")
                    MouseArea {
                        anchors.fill: parent
                        onClicked: sensorsQml.useSensorTag = !sensorsQml.useSensorTag
                    }
                }
            }

            // SensorTag usage
            RowLayout {
                id: switchRowLayout
                anchors.left: useSensorTagColumnLayout.left
                anchors.right: useSensorTagColumnLayout.right

                CustomLabel {
                    id: onSensorTagRowLabel
                    anchors.right: useSensorTagSwitch.left
                    text: qsTr("No")
                    color: 'gray'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: sensorsQml.useSensorTag = false
                    }
                }
                CustomSwitch {
                    id: useSensorTagSwitch
                    anchors.centerIn: parent
                    padding: 0
                    checked: sensorsQml.useSensorTag
                    onCheckedChanged: {
                        sensorsQml.useSensorTag = checked
                        if (sensorsQml.sensorTagConnected) { remoteControlQml.broadcastCommand("USESENSTAG", 0) }
                    }
                }
                CustomLabel {
                    id: offSensorTagRowLabel
                    anchors.left: useSensorTagSwitch.right
                    text: qsTr("Yes");
                    color: 'red'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: sensorsQml.useSensorTag = true
                    }
                }
            }
        }
    }

    ColumnLayout {
        id: mainSensorsColumnLayout
        anchors.centerIn: parent

        CustomLabel {
            id: commentLabel
            text: qsTr("Sensor data may be used or manual input")
        }

        GridLayout {            

            // Changing the total pressure value
            CustomLabel {
                id: samplingPeriodLabel
                anchors.right: samplingFrequencyTextField.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.5
                Layout.column: 0
                Layout.row: 0
                horizontalAlignment: Text.AlignRight
                text: qsTr("Sampling period\n(milliseconds):")
            }
            CustomTextField {
                id: samplingPeriodTextField
                Layout.column: 1
                Layout.row: 0
                implicitWidth: (sensorsQml.humiditySensorLabelText.length === 0) || (sensorsQml.totalPressSensorLabelText.length === 0) || (sensorsQml.temperatureSensorLabelText.length === 0) ? useTotalPressureSensorSwitchRowLayout.width : (commentLabel.width - samplingPeriodLabel.width)
                text: sensorsQml.samplingPeriod
                onEditingFinished: {
                    sensorsQml.samplingPeriod = text
                    remoteControlQml.broadcastCommand("SMPLPERIOD", 0)
                }
            }

            // Changing the number of samples to average
            CustomLabel {
                id: samplesToAverageLabel
                anchors.right: samplesToAverageTextField.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.5
                Layout.column: 0
                Layout.row: 1
                horizontalAlignment: Text.AlignRight
                text: qsTr("Samples to\naverage:")
            }
            CustomTextField {
                id: samplesToAverageTextField
                Layout.column: 1
                Layout.row: 1
                implicitWidth:  (sensorsQml.humiditySensorLabelText.length === 0) || (sensorsQml.totalPressSensorLabelText.length === 0) || (sensorsQml.temperatureSensorLabelText.length === 0) ? useTotalPressureSensorSwitchRowLayout.width : (commentLabel.width - samplingPeriodLabel.width)
                text: sensorsQml.numSamplesToAverage
                onEditingFinished: {
                    sensorsQml.numSamplesToAverage = text
                    remoteControlQml.broadcastCommand("SMPLSTOAVG", 0)
                }
            }

            // Averaging time setup
            CustomLabel {
                id: averagingTimeLabel
                anchors.right: averagingTimeValueLabel.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.4
                Layout.column: 0
                Layout.row: 2
                horizontalAlignment: Text.AlignRight
                text: qsTr("Averaging time:")
            }
            CustomLabel {
                id: averagingTimeValueLabel
                Layout.column: 1
                Layout.row: 2
                color: 'red'
                text: sensorsQml.averagingTime + "  milliseconds"
            }

            Rectangle {
                id: separator1Rect
                Layout.fillWidth: true
                Layout.column: 0
                Layout.row: 3
                height: 1
                color: '#C0C0C0'
            }

            Rectangle {
                id: separator2Rect
                Layout.fillWidth: true
                Layout.column: 1
                Layout.row: 3
                height: 1
                color: '#C0C0C0'
            }

            // Enabling data from the humidity sensor instead of manual values
            CustomLabel {
                id: useHumiditySensorLabel
                anchors.right: (sensorsQml.humiditySensorLabelText.length === 0) ? useHumiditySensorSwitchRowLayout.left : useHumiditySensorUnavailLabel.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.4
                Layout.column: 0
                Layout.row: 4
                horizontalAlignment: Text.AlignRight
                text: (sensorsQml.humiditySensorEnabled) ? qsTr("Water vapor:\n" + sensorsQml.humidity) : qsTr("Water vapor:\n" + sensorsQml.humidity)
            }            
            CustomLabel {
                id: useHumiditySensorUnavailLabel
                Layout.column: 1
                Layout.row: 4
                visible: (sensorsQml.humiditySensorLabelText.length > 0)
                color: 'gray'
                text: sensorsQml.humiditySensorLabelText
            }
            RowLayout {
                id: useHumiditySensorSwitchRowLayout
                Layout.column: 1
                Layout.row: 4
                visible: (sensorsQml.humiditySensorLabelText.length === 0)

                CustomLabel {
                    id: onHumidityRowLabel
                    anchors.right: useHumiditySensorSwitch.left
                    text: qsTr("Manual\nentry")
                    color: 'gray'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useHumiditySensorSwitch.checked = false
                    }
                }
                CustomSwitch {
                    id: useHumiditySensorSwitch
                    anchors.centerIn: parent
                    padding: 0
                    topPadding: coreObj.defaultLabelHeight * 0.4
                    bottomPadding: coreObj.defaultLabelHeight * 0.1
                    checked: sensorsQml.humiditySensorEnabled
                    onCheckedChanged: {
                        sensorsQml.humiditySensorEnabled = checked
                        remoteControlQml.broadcastCommand("USEHUMID", 0)
                    }
                }
                CustomLabel {
                    id: offHumidityRowLabel
                    anchors.left: useHumiditySensorSwitch.right
                    text: qsTr("Use\nsensor");
                    color: 'black'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useHumiditySensorSwitch.checked = true
                    }
                }
            }

            // Enabling data from barometer instead of manual values
            CustomLabel {
                id: useTotalPressureSensorLabel
                anchors.right: (sensorsQml.totalPressSensorLabelText.length === 0) ? useTotalPressureSensorSwitchRowLayout.left : useTotalPressureSensorUnavailLabel.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.4
                Layout.column: 0
                Layout.row: 5
                horizontalAlignment: Text.AlignRight
                text: (sensorsQml.totalPressureSensorEnabled) ? qsTr("Barometer:\n" + sensorsQml.totalPressure) : qsTr("Total pressure:\n" + sensorsQml.totalPressure)
            }
            CustomLabel {
                id: useTotalPressureSensorUnavailLabel
                Layout.column: 1
                Layout.row: 5
                visible: (sensorsQml.totalPressSensorLabelText.length > 0)
                color: 'gray'
                text: sensorsQml.totalPressSensorLabelText
            }
            RowLayout {
                id: useTotalPressureSensorSwitchRowLayout
                Layout.column: 1
                Layout.row: 5
                visible: (sensorsQml.totalPressSensorLabelText.length === 0)

                CustomLabel {
                    id: onTotalPressureRowLabel
                    anchors.right: useTotalPressureSensorSwitch.left
                    text: qsTr("Manual\nentry")
                    color: 'gray'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useTotalPressureSensorSwitch.checked = false
                    }
                }
                CustomSwitch {
                    id: useTotalPressureSensorSwitch
                    anchors.centerIn: parent
                    padding: 0
                    topPadding: coreObj.defaultLabelHeight * 0.4
                    bottomPadding: coreObj.defaultLabelHeight * 0.1
                    checked: sensorsQml.totalPressureSensorEnabled
                    onCheckedChanged: {
                        sensorsQml.totalPressureSensorEnabled = checked
                        remoteControlQml.broadcastCommand("USEBAROM", 0)
                    }
                }
                CustomLabel {
                    id: offTotalPressureRowLabel
                    anchors.left: useTotalPressureSensorSwitch.right
                    text: qsTr("Use\nsensor");
                    color: 'black'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useTotalPressureSensorSwitch.checked = true
                    }
                }
            }

            // Enabling data from barometer instead of manual values
            CustomLabel {
                id: useTemperatureSensorLabel
                anchors.right: (sensorsQml.temperatureSensorLabelText.length === 0) ? useTemperatureSensorSwitchRowLayout.left : useTemperatureSensorUnavailLabel.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.4
                Layout.column: 0
                Layout.row: 6
                horizontalAlignment: Text.AlignRight
                text: (sensorsQml.temperatureSensorEnabled) ? qsTr("Thermometer:\n" + sensorsQml.temperature) : qsTr("Temperature:\n" + sensorsQml.temperature)
            }            
            CustomLabel {
                id: useTemperatureSensorUnavailLabel
                Layout.column: 1
                Layout.row: 6
                visible: (sensorsQml.temperatureSensorLabelText.length > 0)
                color: 'gray'
                text: sensorsQml.temperatureSensorLabelText
            }
            RowLayout {
                id: useTemperatureSensorSwitchRowLayout
                Layout.column: 1
                Layout.row: 6
                visible: (sensorsQml.temperatureSensorLabelText.length === 0)

                CustomLabel {
                    id: onTemperatureRowLabel
                    anchors.right: useTemperatureSensorSwitch.left
                    text: qsTr("Manual\nentry")
                    color: 'gray'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useTemperatureSensorSwitch.checked = false
                    }
                }
                CustomSwitch {
                    id: useTemperatureSensorSwitch
                    anchors.centerIn: parent
                    padding: 0
                    topPadding: coreObj.defaultLabelHeight * 0.4
                    bottomPadding: coreObj.defaultLabelHeight * 0.1
                    checked: sensorsQml.temperatureSensorEnabled
                    onCheckedChanged: {
                        sensorsQml.temperatureSensorEnabled = checked
                        remoteControlQml.broadcastCommand("USETHERM", 0)
                    }
                }
                CustomLabel {
                    id: offTemperatureRowLabel
                    anchors.left: useTemperatureSensorSwitch.right
                    text: qsTr("Use\nsensor");
                    color: 'black'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useTemperatureSensorSwitch.checked = true
                    }
                }
            }
        }

        Rectangle {
            id: separator0Rect
            Layout.fillWidth: true
            Layout.column: 0
            Layout.row: 3
            height: 1
            color: '#C0C0C0'
            visible: (Screen.primaryOrientation === Qt.PortraitOrientation) ? true : false
        }
    }
}
