// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component to specify the total pressure of the gas mixture
import QtQuick 2.9
import QtQuick.Controls 2.2
import QtQuick.Layouts 1.3

Item {

    id: totalPressureItem
    anchors.fill: parent

    // Rectangle to shade the background
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: 'black'
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        anchors.fill: mainTotalPressureColumnLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        color: "white"
        border.width: 1
        border.color: 'gray'
        radius: coreObj.defaultLabelHeight * 0.5
    }

    // Exit button
    CustomButton {
        id: exitButton
        anchors.top: totalPressureItem.top
        anchors.right: totalPressureItem.right
        anchors.margins: coreObj.defaultLabelHeight * (0.1)
        implicitWidth: 1.5 * exitButton.height
        text: qsTr("X")
        onClicked: {
            molListViewModel.updatePartPress();  // Need to also update the values displayed in the molecules list (partial pressures)
            totalPressureItem.destroy();
        }
    }

    CustomLabel {
        id: widthLabel
        text: qsTr("Gas mixture total pressure units and value")
        visible: false
        enabled: false
    }

    // Column layout to hold all the interface items
    ColumnLayout {
        // At rotation the buttons are not positioned exactly the way they should be (fix this)
        id: mainTotalPressureColumnLayout
        anchors.centerIn: parent        
        Layout.fillWidth: true
        Layout.fillHeight: true
        spacing: 5
        CustomLabel {
            id: commentLabel
            Layout.fillWidth: true            
            text: qsTr("Gas mixture total pressure units and value")
        }

        GridLayout {

            // Enabling data from barometer instead of manual values
            CustomLabel {
                id: useSensorLabel
                anchors.right: useSensorSwitchRowLayout.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.4
                Layout.column: 0
                Layout.row: 0
                horizontalAlignment: Text.AlignRight
                visible: sensorsQml.totalPressureSensorIsPresent
                text: qsTr("Value to use:")
            }
            RowLayout {
                id: useSensorSwitchRowLayout
                Layout.column: 1
                Layout.row: 0
                visible: sensorsQml.totalPressureSensorIsPresent

                CustomLabel {
                    id: onRowLabel
                    anchors.right: useSensorSwitch.left
                    text: qsTr("Manual\nentry")
                    color: 'gray'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useSensorSwitch.checked = false
                    }
                }
                CustomSwitch {
                    id: useSensorSwitch
                    anchors.centerIn: parent
                    padding: 0
                    topPadding: coreObj.defaultLabelHeight * 0.4
                    bottomPadding: coreObj.defaultLabelHeight * 0.1
                    checked: sensorsQml.totalPressureSensorEnabled
                    onCheckedChanged: {
                        sensorsQml.totalPressureSensorEnabled = checked
                        remoteControlQml.broadcastCommand("USEBAROM", 0)
                    }
                }
                CustomLabel {
                    id: offRowLabel
                    anchors.left: useSensorSwitch.right
                    text: qsTr("Sensor\nvalue");
                    color: 'red'
                    MouseArea {
                        anchors.fill: parent
                        onClicked: useSensorSwitch.checked = true
                    }
                }
            }

            // Changing the Pathlength value
            CustomLabel {
                id: totalPressureValueLabel
                anchors.right: totalPressureTextField.left
                anchors.rightMargin: coreObj.defaultLabelHeight * 0.4
                Layout.column: 0
                Layout.row: 1
                horizontalAlignment: Text.AlignRight
                text: qsTr("Total pressure:")
            }            
            CustomTextField {
                id: totalPressureTextField
                Layout.column: 1
                Layout.row: 1
                implicitWidth: widthLabel.width - totalPressureValueLabel.width
                text: totalPressQml.totalPressure
                readOnly: sensorsQml.totalPressureSensorEnabled
                onEditingFinished: {
                    totalPressQml.totalPressure = text  // See if this gets blocked when ReadOnly
                    remoteControlQml.broadcastCommand("TPRES", 0)
                }
            }            
        }

        // ComboBox to select the pathlength units
        CustomComboBox {
            id: unitsComboBox
            Layout.fillWidth: true
            model: [ "Atmospheres, atm", "Millibar, mbar", "Torr, Torr", "Pascal, Pa", "Pounds per square inch, psi"]
            currentIndex: totalPressQml.units
            onCurrentIndexChanged: totalPressQml.units = currentIndex
        }
    }
}
