// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Auxiliary functions used in the program
#ifndef AUXILIARY_H
#define AUXILIARY_H

#include "spectrum.h"
#include <cmath>
#include "complex.h"

class Auxiliary
{
public:
    Auxiliary();

    // Copying the spectrum data from one variable to another
    static void copySpectrum(Spectrum *from, Spectrum *to);

    // Method to carry out selection sort algorithm on an array
    static void selectionSort(QVector<int> *array);
    static void selectionSort(QVector<double> *array);

    // Method to find the maximum value in an array (real and imaginary implementations)
    static double maximum(QVector<double> *array);
    //static std::complex<double> maximum(QVector<std::complex<double> > *array);

    // Method to find the minimum value in an array (real and imaginary implementation)
    static double minimum(QVector<double> *array);
    //static std::complex<double> minimum(QVector<std::complex<double> > *array);

    // Method to check the numerical input to avoid value acceptance when not needed
    static bool acceptInput(QString value);

};

#endif // AUXILIARY_H
