// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


// Class is used to discover available devices and the Bluetooth services
#ifndef BLUETOOTHDISCOVERDEVICES_H
#define BLUETOOTHDISCOVERDEVICES_H

#include <QObject>
#include <QString>
#include <QBluetoothServiceInfo>
#include <QBluetoothLocalDevice>
#include <QBluetoothDeviceDiscoveryAgent>

class BluetoothDiscoverDevices : public QObject
{
    Q_OBJECT
public:
    explicit BluetoothDiscoverDevices(QObject *parent = nullptr);

    // Method to get a reference to the object used to discover bluetooth devices
    QBluetoothDeviceDiscoveryAgent *getBluetoothDeviceDiscoveryAgent();

    // Initializing device and connections
    void discoverDevices(bool isLowEnergyMode);

    // Methods to get the connected device index
    qint8 getConnectedDeviceIndex();

    // Method to get selected device address
    QBluetoothDeviceInfo getSelectedDevice();
    // Methods to get and set the selected device index
    quint8 getSelectedDeviceIndex();
    void setSelectedDeviceIndex(quint8 newSelectedDeviceIndex);

signals:

    void deviceDiscoveryStarted();   // Signal is emitted when the device discovery is started
    void deviceDiscoveryFinished();  // Signal is emitted when the bluetooth device discovery is finished

    void connected();     // Signal is emitted when the device is connected
    void disconnected();  // Signal is emitted when the device is disconnected

private slots:

    // Slot is called when a device is connected
    void setDeviceConnected();

    // Slot is called when the device is disconnected
    void setDeviceDisconnected();

public slots:

private:

    // Bluetooth local device object
    QBluetoothLocalDevice *localDevice;

    // Bluetooth device discovery service
    QBluetoothDeviceDiscoveryAgent *discoveryAgent;

    // Connected device index
    qint8 connectedDeviceIndex;

    // Variable holds the index of the selected device
    quint8 selectedDeviceIndex;

};

#endif // BLUETOOTHDISCOVERDEVICES_H
