// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object to request data from the HITRAN-online server
#ifndef HITRANREQUESTDATA_H
#define HITRANREQUESTDATA_H

#include <QObject>
#include <QNetworkAccessManager>
#include <QNetworkReply>
#include "filedownloader.h"

class HitranRequestData : public QObject
{
    Q_OBJECT
public:

    explicit HitranRequestData(QObject *parent = 0);

    // Method to send a request to a remote server
    void requestDataFromRemoteHost();

    // Methods to get and set the requests to be sent to the remote server
    QString getRequestStr();
    void setRequestStr(QString newRequestStr);

signals:

    // Signal returns the downloaded HITRAN data
    void hitranDataReturned(QByteArray *hitranData, bool success);

    // Signal used to send notifications to the user of what is going on in the program
    void notify(QString message, double value, bool visible, bool cancelButtonVisible);

private slots:

    // Slot executed when a reply is received from the network
    void onFinished(QNetworkReply *reply);

    // Slot is executed when with the download progress updates
    void onDownloadProgressUpdate(qint64 bytesReceived, qint64 bytesToAquire);

    // Slot is executed when there an error receiving reply from a network request
    void onReplyError(QNetworkReply::NetworkError error);

private:

    // Method to create actions
    void createActions();

    // Manager to access data from a remote host
    QNetworkAccessManager *networkManager;

    // Network reply variable to get data returned from HITRANonline
    QNetworkReply *reply;

    // String with the request to be sent to a remote server
    QString requestStr;

    // Object to carry out downloads of a remote file
    FileDownloader *downloader;

    // Boolean variable determined from the returned data indicating if it involves the authentication case
    bool authenCase;

};

#endif // HITRANREQUESTDATA_H
