// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Data object to connect the calculation module with the QML form to specify the instrument function to use
#ifndef INSTRUMENTFUNCTIONQML_H
#define INSTRUMENTFUNCTIONQML_H

#include <QObject>
#include <QLocale>
#include "bytrancore.h"

class InstrumentFunctionQml : public QObject
{
    Q_OBJECT

    Q_PROPERTY(int instrFunctIndex  READ instrFunctIndex  WRITE setInstrFunctIndex  NOTIFY instrFunctIndexChanged)
    Q_PROPERTY(QString instrResol READ instrResol WRITE setInstrResol NOTIFY instrResolChanged)
    Q_PROPERTY(QString instrFunctWing READ instrFunctWing WRITE setInstrFunctWing NOTIFY instrFunctWingChanged)

public:

    explicit InstrumentFunctionQml(QObject *parent = nullptr, BytranCore *inCore = nullptr);

    // Methods to get and set the instrumental function indexes
    quint8 instrFunctIndex() const;
    void setInstrFunctIndex(const quint8 &instrFunctIndex);

    // Methods to get and set the instrumental function resolution
    QString instrResol() const;
    void setInstrResol(const QString &instrResol);

    // Methods to get and set the instrumental function wing
    QString instrFunctWing() const;
    void setInstrFunctWing(const QString &instrFunctWing);

signals:

    // Signal emited when the instrumental function is changed
    void instrFunctIndexChanged();
    void instrResolChanged();
    void instrFunctWingChanged();

private slots:

    // Slot is used to update all values in the corresponding QML dialog
    void setUpdatedValues();

private:

    // Instrumental function
    // 0 - None
    // 1 - Rectangular (Boxcar)
    // 2 - Triangular
    // 3 - Gaussian
    // 4 - Dispersion (Lorentz)
    // 5 - Diffraction
    // 6 - Michelson
    quint8 m_instrFunctIndex;  // Instrumental function

    // Instrumental resolution, cm-1
    QString m_instrResol;

    // Instrumental function wing, cm-1
    QString m_instrFunctWing;

    // Core object with the calculation logic etc.
    BytranCore *core;

    // Locale specific string to number and inverse conversions
    QLocale loc;

};

#endif // INSTRUMENTFUNCTIONQML_H
