// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Class to contain calcualted spectra for a single layer (currently the molecules and composite spectra), the isotopes and separate lines may be added later if need be
#include "onelayerspectra.h"

OneLayerSpectra::OneLayerSpectra()
{

}

// Methods to get the unprocessed and the instrument function processed cross-sectional spectra
Spectrum *OneLayerSpectra::getCrossSect() { return &(this->crossSectionSpectrum); }
Spectrum *OneLayerSpectra::getInstrFunctCrossSect() { return &(this->instFunctCrossSectSpectrum); }

// Methods to get and set the composite spectrum (unprocessed and that processed with the instrument function)
Spectrum *OneLayerSpectra::getOptDepth() { return &(this->compositeSpectrum); }
Spectrum *OneLayerSpectra::getInstrFunctOptDepth() { return &(this->instrFunctSpectrum); }

// Method to get the plain (unprocessed and that processed with the instrument function radiance spectruum)
Spectrum *OneLayerSpectra::getPlainRadiance() { return &(this->plainRadiance); }
Spectrum *OneLayerSpectra::getInstrFunctRadiance() { return &(this->instrFunctRadiance); }

// Methods to get and set the molecular attenuation spectra
QVector<OneMolSpectra> *OneLayerSpectra::getMol() { return &(this->molSpectra); }

// Method to get and set the molecular spectra at a specified index
OneMolSpectra *OneLayerSpectra::getMolAt(int index) { return &(this->molSpectra[index]); }

// Method to return a spectrum of interest (any type of spectrum based on the spectrum index)
Spectrum *OneLayerSpectra::getSpec(int composite, int mol, int iso, long line)
{
    // Returning composite spectrum for a given layer
    if (composite == 0)
    {
        // Means it is not a separate line spectrum
        if (line == 0) {
            // Means it is not an isotope spectrum
            if (iso == 0)  {
                return this->molSpectra[mol].getOptDepth();  // Returning a molecular spectrum according to the indices
            }
            else {
                return 0;  // Returning an isotope spectrum according to the indices
            }
        }
        else {
            return 0;
        }
    }
    else {
        return &(this->compositeSpectrum);
    }
}


