// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object with spectra for a single molecule
#ifndef ONEMOLSPECTRA_H
#define ONEMOLSPECTRA_H

#include "spectrum.h"
#include "oneisospectra.h"
#include <QVector>

class OneMolSpectra
{
public:

    OneMolSpectra();

    // Method to return a pointer to the isotope spectra
    QVector<OneIsoSpectra> *getIso();

    // Method to get an isotope spectrum at a specific index
    OneIsoSpectra *getIsoAt(int index);

    // Method to get the molecule spectrum
    Spectrum *getOptDepth();

    // Method to get the radiance spectrum for this molecule
    Spectrum *getRadiance();

    // Method to get the absorption cross-sections spectrum for a given molecule
    Spectrum *getCrossSect();

private:

    // Isotope spectra
    QVector<OneIsoSpectra> isoSpectra;

    // Molecule spectrum for a given molecule
    Spectrum optDepthSpectrum;

    // Radiance spectrum for one molecule
    Spectrum radianceSpectrum;

    // Absorption cross-section spectrum for the given molecule
    Spectrum crossSectSpectrum;

};

#endif // ONEMOLSPECTRA_H
