// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The functionality of this module is based on the examples provided with the Qt Labs Sense HAT add-on
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


// Object to access the SenseHat sensors (Temperature, Pressure and Humidity)
#include "sensehat.h"
#include <QLoggingCategory>
#ifdef QT_SENSEHAT_LIB
    #include <unistd.h>
#endif
#include <QDebug>

SenseHat::SenseHat(QObject *parent) : QObject(parent)
{
    #ifdef QT_SENSEHAT_LIB  // Sense hat is only included for the defined platforms (when compiled for Raspberry Pi, see the PRO file)
        QLoggingCategory::setFilterRules(QStringLiteral("qt.sensehat=true"));
        sensors.setAutoPoll(true);
    #endif
}

// Methods to get the last recorded values from sensors
double SenseHat::getTotalPressure()
{
    #ifdef QT_SENSEHAT_LIB  // Sense hat is only included for the defined platforms (when compiled for Raspberry Pi, see the PRO file)
        return sensors.pressure();
    #else
        return 0;
    #endif
}
double SenseHat::getTemperature()
{
    #ifdef QT_SENSEHAT_LIB  // Sense hat is only included for the defined platforms (when compiled for Raspberry Pi, see the PRO file)
        return sensors.temperature();
    #else
        return 0;
    #endif
}
double SenseHat::getHumidity()
{
    #ifdef QT_SENSEHAT_LIB  // Sense hat is only included for the defined platforms (when compiled for Raspberry Pi, see the PRO file)
        return sensors.humidity();
    #else
        return 0;
    #endif
}

// Method to let the rest of the code know if the Sense HAT is available
bool SenseHat::getSenseHatIsPresent()
{
    #ifdef QT_SENSEHAT_LIB  // Sense hat is only included for the defined platforms (when compiled for Raspberry Pi, see the PRO file)
        if ((sensors.humidity() <= 0) && (sensors.pressure() <= 0)) { return false; }  // Temperature is not included as it may be negative
        else { return true; }
    #else
        return false;
    #endif
}
