// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The functionality of this module is based on the examples provided with the Qt Labs Sense Hat add-on
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


// Object to access the SenseHat sensors (Temperature, Pressure and Humidity)
#ifndef SENSEHAT_H
#define SENSEHAT_H

#include <QObject>
#include <QtGlobal>
#ifdef QT_SENSEHAT_LIB  // Sense hat is only included for the defined platforms (when compiled for Raspberry Pi, see the PRO file)
    #include <QSenseHatSensors>
#endif

class SenseHat : public QObject
{
    Q_OBJECT
public:
    explicit SenseHat(QObject *parent = nullptr);

    // Methods to get the current values from sensors
    double getTotalPressure();
    double getTemperature();
    double getHumidity();

    // Method to let the rest of the code know if the Sense HAT is available
    bool getSenseHatIsPresent();

signals:

public slots:

private:

    #ifdef QT_SENSEHAT_LIB  // Sense hat is only included for the defined platforms (when compiled for Raspberry Pi, see the PRO file)
        QSenseHatSensors sensors;  // Sense HAT sensors object
    #endif

};

#endif // SENSEHAT_H
