// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// This list model is used to display a list of available ports on a device
#ifndef SERIALPORTSLISTMODEL_H
#define SERIALPORTSLISTMODEL_H

#include <QObject>
#include "bytrancore.h"
#include <QAbstractListModel>

class SerialPortsListView
{
public:

    SerialPortsListView(const QString &portName);
    QString portName() const;

    void setPortName(const QString &portName);

private:

    QString m_portName;

};

class SerialPortsListModel : public QAbstractListModel
{
    Q_OBJECT

public:

    Q_INVOKABLE void updateDisplayed();

    explicit SerialPortsListModel(QObject *parent = nullptr, BytranCore *inCore = 0);

    enum SerialPortsListViewRoles {
        serialPortRole = Qt::UserRole + 1,
    };

    void addElement(const SerialPortsListView &serialPortsListView);
    void removeAllElements();
    int rowCount(const QModelIndex & parent = QModelIndex()) const;
    QVariant data(const QModelIndex & index, int role = Qt::DisplayRole) const;

    // Method to set the data when the values in the model are modified
    bool setData(const QModelIndex & index, const QVariant & value, int role);

signals:

public slots:

protected:

    QHash<int, QByteArray> roleNames() const;

private:

    BytranCore *core;  // Pointer to the core object
    QList<SerialPortsListView> m_serialPortsListView;  // List with port names

};

#endif // SERIALPORTSLISTMODEL_H
