// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | bytran@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object is used to relay the wavelength information betweeen the C++ data objects and the QML interface
// All the data conversion code may better be moved into the Core module so the values retured are in the right
// units, otherwise this will have to be reimplemented for every component where units conversion is taking place
#ifndef WAVELENGTHQML_H
#define WAVELENGTHQML_H

#include <QObject>
#include <QLocale>
#include "bytrancore.h"

class WavelengthQml : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QString startWavelength READ startWavelength WRITE setStartWavelength NOTIFY startWavelengthChanged)
    Q_PROPERTY(QString endWavelength READ endWavelength WRITE setEndWavelength NOTIFY endWavelengthChanged)
    Q_PROPERTY(QString resolWavelength READ resolWavelength NOTIFY resolWavelengthChanged)
    Q_PROPERTY(quint8 units READ units WRITE setUnits NOTIFY unitsChanged)
    Q_PROPERTY(int numPoints READ numPoints WRITE setNumPoints NOTIFY numPointsChanged)

public:

    explicit WavelengthQml(QObject *parent = 0, BytranCore *inCore = 0);
    WavelengthQml(const QString &startWavelength, const QString &endWavelength, const QString &resolWavelength, const int &units, QObject *parent=0);

    // Start wavelength
    QString startWavelength() const;
    void setStartWavelength(const QString &startWavelength);

    // End wavelength
    QString endWavelength() const;
    void setEndWavelength(const QString &endWavelength);

    // Wavelength resolution
    QString resolWavelength() const;

    // Wavelength units
    quint8 units() const;
    void setUnits(const quint8 &units);

    // Number of points
    int numPoints() const;
    void setNumPoints(const int &numPoints);

signals:

    void startWavelengthChanged();
    void endWavelengthChanged();
    void resolWavelengthChanged();
    void unitsChanged();
    void numPointsChanged();

private slots:

    // Slot is used to update all values in the corresponding QML dialog
    void setUpdatedValues();

private:

    QString m_startWavelength;
    QString m_endWavelength;
    QString m_resolWavelength;    
    int m_numPoints;
    int m_units;

    // Core object with the calculation logic etc.
    BytranCore *core;

    // Locale specific string to number and inverse conversions
    QLocale loc;

};

#endif // WAVELENGTHQML_H
